@@ -17,9 +17,7 @@
 #include <ctype.h>
 #include "aedit.h"
 
-int
-set_baselines(arg1,arg2,remarg)
-char *arg1, *arg2, *remarg;
+int set_baselines(char *arg1, char *arg2, char *remarg)
 {
 	extern struct inputs inp;
 	char outbuf[150], buf[150];
