@@ -9,11 +9,11 @@
 #include "control.h"
 #include "mk4_sizes.h"
 
+// f (from) is source pointer
+// t (to)   is destination pointer
 
 int
-copy_cblock_parts (f,t)
-struct c_block *f,*t;               // f (from) is source pointer
-                                    // t (to)   is destination pointer
+copy_cblock_parts ( struct c_block* f, struct c_block* t)
     {
     int i,j;
 
@@ -134,6 +134,12 @@ struct c_block *f,*t;               // f (from) is source pointer
     if (f->mbd_anchor != NULLINT)
         t->mbd_anchor = f->mbd_anchor;
 
+    if (f->ion_smooth != NULLINT)
+        t->ion_smooth = f->ion_smooth;
+
+    if (f->est_pc_manual != NULLINT)
+        t->est_pc_manual = f->est_pc_manual;
+
     if (f->nsamplers != NULLINT)
         {
         t->nsamplers = f->nsamplers;
@@ -186,8 +192,25 @@ struct c_block *f,*t;               // f (from) is source pointer
 
         if (f->adhoc_file_chans[i][0] != 0)
             strcpy (t->adhoc_file_chans[i], f->adhoc_file_chans[i]);
+        
+        if (f->pc_phase_offset[i].rem != NULLFLOAT)
+            t->pc_phase_offset[i].rem = f->pc_phase_offset[i].rem;
+            
+        if (f->pc_phase_offset[i].ref != NULLFLOAT)
+            t->pc_phase_offset[i].ref = f->pc_phase_offset[i].ref;
         }
 
+    if (f->gen_cf_record != NULLINT)
+        t->gen_cf_record = f->gen_cf_record;
+    if (f->nnotches != NULLINT)
+        t->nnotches = f->nnotches;
+    for (i=0; i<MAXFREQ; i++)
+        {
+        if (f->notches[i][0] != NULLFLOAT)
+            t->notches[i][0] = f->notches[i][0];
+        if (f->notches[i][1] != NULLFLOAT)
+            t->notches[i][1] = f->notches[i][1];
+        }
 
     if (f->index[0] != NULLINT)     // this needs work (deprecated)
         for (i=0; i<32; i++)
@@ -229,11 +252,20 @@ struct c_block *f,*t;               // f (from) is source pointer
             if (f->gates[i].duration != NULLINT)
                 t->gates[i].duration = f->gates[i].duration;
 
-            if (f->delay_offs[i].ref != NULLFLOAT)
-                t->delay_offs[i].ref = f->delay_offs[i].ref;
+            if (f->delay_offs[i].ref != NULLFLOAT)              // ##DELAY_OFFS##
+                t->delay_offs[i].ref = f->delay_offs[i].ref;    // ##DELAY_OFFS##
 
-            if (f->delay_offs[i].rem != NULLFLOAT)
-                t->delay_offs[i].rem = f->delay_offs[i].rem;
+            if (f->delay_offs[i].rem != NULLFLOAT)              // ##DELAY_OFFS##
+                t->delay_offs[i].rem = f->delay_offs[i].rem;    // ##DELAY_OFFS##
+
+            for (j=0; j<2; j++)     // copy delays for both polarizations
+                {
+                if (f->delay_offs_pol[i][j].ref != NULLFLOAT)
+                    t->delay_offs_pol[i][j].ref = f->delay_offs_pol[i][j].ref;
+
+                if (f->delay_offs_pol[i][j].rem != NULLFLOAT)
+                    t->delay_offs_pol[i][j].rem = f->delay_offs_pol[i][j].rem;
+                }
             }
         }
 
