@@ -12,8 +12,6 @@
 #include <string.h>
 #include "control.h"
 #include "parser.h"
-#include "mk4_data.h"
-#include "pass_struct.h"
 #include "param_struct.h"
 
 #define IS_CONTROL_FILE 1
@@ -29,35 +27,53 @@ struct fsm_table_entry *fsm_base;
 int *line_end;
 
 int
-parse_control_file (char* control_file_name)
+parse_control_file (char* control_file_name,
+                    char** control_file_buff,  //stash stripped but unparsed contents of control file
+                    char** set_string_buff     //stash stripped but unparsed contents of set commands
+)
     {
     int n;
     int flag = 0;
     char *input_string;
-    
-    //static char arrays to store the stipped down control strings
-    static char* control_file_string;
-    static char* set_string;
     extern struct type_param param;
-    
+
                                                    /* read input control file */ 
     if (read_control_file (control_file_name,&input_string, &flag) != 0) 
         {
-        msg ("Error opening control file %s", 2, control_file_name);
+        msg ("Error opening control file %s \n", 2, control_file_name);
         return (-1);
         }
-        
+
     //these strings are malloced here so we can can save them to the type_222 
     //record later, they will be freed at the end of fourfit main 4/7/17 JPB
+    //this is not a perfect solution, as it relies on this function only ever
+    //being called with control_file_buff = param.control_file_buff
+    //and set_string_buff = param.set_string_buff, this probably needs to be revised
     if(flag == IS_CONTROL_FILE)
         {
-        param.control_file_buff = (char*) malloc( strlen(input_string) + 1 );
-        strcpy(param.control_file_buff, input_string);
+        if(*control_file_buff != NULL)
+            {   
+            free(*control_file_buff);
+            *control_file_buff = (char*) malloc( strlen(input_string) + 1 );
+            }
+        else
+            {
+            *control_file_buff = (char*) malloc( strlen(input_string) + 1 );
+            }
+        strcpy(*control_file_buff, input_string);
         }
     else if(flag == IS_SET_STRING)
         {
-        param.set_string_buff = (char*) malloc( strlen(input_string) + 1 );
-        strcpy(param.set_string_buff, input_string);
+        if(*set_string_buff != NULL)
+            {   
+            free(*set_string_buff);
+            *set_string_buff = (char*) malloc( strlen(input_string) + 1 );
+            }
+        else
+            {
+            *set_string_buff = (char*) malloc( strlen(input_string) + 1 );
+            }
+        strcpy(*set_string_buff, input_string);
         }
         
                                                   /* perform lexical analysis */
